Documentation
¶
Index ¶
- Variables
- func AddRestrictionTypeFunc(bot *telebot.Bot, c telebot.Context, groupChatID int64, groupChatName string, ...) error
- func AddVerificationParamsHandler(bot *telebot.Bot) func(c telebot.Context) error
- func CheckAdminHandler(bot *telebot.Bot) func(c telebot.Context) error
- func DeleteAllVerificationParamsHandler(bot *telebot.Bot) func(c telebot.Context) error
- func DeleteAllVerifiedUsersHandler(bot *telebot.Bot) func(c telebot.Context) error
- func GetAuthTokenFromAdmin(groupID int64, userID int64) (string, bool)
- func ListVerificationParamsHandler(bot *telebot.Bot) func(c telebot.Context) error
- func ListenForstorage_dbChanges(bot *telebot.Bot)
- func NewUserJoinedHandler(bot *telebot.Bot) func(c telebot.Context) error
- func SetActiveVerificationParamsHandler(bot *telebot.Bot) func(c telebot.Context) error
- func SetTypeRestrictionHandler(bot *telebot.Bot) func(c telebot.Context) error
- func SetupHandler(bot *telebot.Bot) func(c telebot.Context) error
- func StartHandler(bot *telebot.Bot) func(c telebot.Context) error
- func TestVerificationHandler(bot *telebot.Bot) func(c telebot.Context) error
- func UnifiedHandler(bot *telebot.Bot) func(c telebot.Context) error
- func VerifiedUsersListHeandler(bot *telebot.Bot) func(c telebot.Context) error
- func VerifyHandler(bot *telebot.Bot) func(c telebot.Context) error
Constants ¶
This section is empty.
Variables ¶
var DataMutex sync.Mutex
Functions ¶
func AddRestrictionTypeFunc ¶
func AddRestrictionTypeFunc(bot *telebot.Bot, c telebot.Context, groupChatID int64, groupChatName string, isFirstParameter bool) error
Unified logic to set restriction type add_type_restriction_func
func AddVerificationParamsHandler ¶
AddVerificationParamsHandler handles adding verification parameters in a single step /add_verification_params
func CheckAdminHandler ¶
/check_admin command - check administrator rights in a group and verify verification parameters
func DeleteAllVerificationParamsHandler ¶
Handler deleting all verification parameters for a group /delete_all_verification_params
func DeleteAllVerifiedUsersHandler ¶
Handler for delering all verified users /delete_all_verified_users for the group
func ListVerificationParamsHandler ¶
ListVerificationParamsHandler displays the list of added verification parameters /list_verification_params
func ListenForstorage_dbChanges ¶
Store change listener
func NewUserJoinedHandler ¶
A new user has joined the group
func SetActiveVerificationParamsHandler ¶
Handler to switch active verification parameters /set_active_verification_params
func SetTypeRestrictionHandler ¶
Handler for /set_type_restriction
func SetupHandler ¶
/setup command - administrator initiates configuration
func StartHandler ¶
Handler for /start
func TestVerificationHandler ¶
Handler for /test_verification
func VerifiedUsersListHeandler ¶
heandler for /verified_users_list
Types ¶
This section is empty.